'use strict';

function _interopDefault (ex) { return (ex && (typeof ex === 'object') && 'default' in ex) ? ex['default'] : ex; }

var assign = _interopDefault(require('nano-assign'));

// eslint-disable-next-line no-unused-vars
var MonacoEditor$1 = {
  name: 'MonacoEditor',

  props: {
    value: String,
    theme: {
      type: String,
      default: 'vs'
    },
    language: String,
    options: Object,
    placeholder: null,
    require: {
      type: Function,
      default: window.require
    }
  },

  model: {
    event: 'change'
  },

  data: function data() {
    return {
      editorLoaded: false
    }
  },

  watch: {
    options: {
      deep: true,
      handler: function handler(options) {
        if (this.editor) {
          this.editor.updateOptions(options);
        }
      }
    },

    value: function value(newValue) {
      if (this.editor) {
        if (newValue !== this.editor.getValue()) {
          this.editor.setValue(newValue);
        }
      }
    },

    language: function language(newVal) {
      if (this.editor) {
        window.monaco.editor.setModelLanguage(this.editor.getModel(), newVal);
      }
    },

    theme: function theme(newVal) {
      if (this.editor) {
        window.monaco.editor.setTheme(newVal);
      }
    }
  },

  mounted: function mounted() {
    var this$1 = this;

    var options = assign({}, {value: this.value,
      theme: this.theme,
      language: this.language},
      this.options);

    this.require(['vs/editor/editor.main'], function () {
      this$1.editorLoaded = true;
      this$1.editor = window.monaco.editor.create(this$1.$el, options);
      this$1.$emit('editorMount', this$1.editor);
      this$1.editor.onContextMenu(function (event) { return this$1.$emit('contextMenu', event); });
      this$1.editor.onDidBlurEditor(function () { return this$1.$emit('blur'); });
      this$1.editor.onDidBlurEditorText(function () { return this$1.$emit('blurText'); });
      this$1.editor.onDidChangeConfiguration(function (event) { return this$1.$emit('configuration', event); }
      );
      this$1.editor.onDidChangeCursorPosition(function (event) { return this$1.$emit('position', event); }
      );
      this$1.editor.onDidChangeCursorSelection(function (event) { return this$1.$emit('selection', event); }
      );
      this$1.editor.onDidChangeModel(function (event) { return this$1.$emit('model', event); });
      this$1.editor.onDidChangeModelContent(function (event) {
        var value = this$1.editor.getValue();
        if (this$1.value !== value) {
          this$1.$emit('change', value, event);
        }
      });
      this$1.editor.onDidChangeModelDecorations(function (event) { return this$1.$emit('modelDecorations', event); }
      );
      this$1.editor.onDidChangeModelLanguage(function (event) { return this$1.$emit('modelLanguage', event); }
      );
      this$1.editor.onDidChangeModelOptions(function (event) { return this$1.$emit('modelOptions', event); }
      );
      this$1.editor.onDidDispose(function (event) { return this$1.$emit('afterDispose', event); });
      this$1.editor.onDidFocusEditor(function () { return this$1.$emit('focus'); });
      this$1.editor.onDidFocusEditorText(function () { return this$1.$emit('focusText'); });
      this$1.editor.onDidLayoutChange(function (event) { return this$1.$emit('layout', event); });
      this$1.editor.onDidScrollChange(function (event) { return this$1.$emit('scroll', event); });
      this$1.editor.onKeyDown(function (event) { return this$1.$emit('keydown', event); });
      this$1.editor.onKeyUp(function (event) { return this$1.$emit('keyup', event); });
      this$1.editor.onMouseDown(function (event) { return this$1.$emit('mouseDown', event); });
      this$1.editor.onMouseLeave(function (event) { return this$1.$emit('mouseLeave', event); });
      this$1.editor.onMouseMove(function (event) { return this$1.$emit('mouseMove', event); });
      this$1.editor.onMouseUp(function (event) { return this$1.$emit('mouseUp', event); });
    });
  },

  beforeDestroy: function beforeDestroy() {
    this.editor && this.editor.dispose();
  },

  methods: {
    getMonaco: function getMonaco() {
      return this.editor
    },

    focus: function focus() {
      this.editor.focus();
    }
  },

  render: function render(h) {
    return h('div', null, [this.editorLoaded ? null : this.placeholder])
  }
};

if (typeof window !== 'undefined' && window.Vue) {
  window.Vue.component(MonacoEditor$1.name, MonacoEditor$1);
}

module.exports = MonacoEditor$1;
